From c6316bdcc9779cdeb882293b3f6813c56284672f Mon Sep 17 00:00:00 2001
From: slerena <slerena@gmail.com>
Date: Tue, 2 Sep 2008 11:55:54 +0000
Subject: [PATCH] 2008-09-02  Sancho Lerena <slerena@gmail.com>

        *  extensions/update_manager*: Updated GPL header. Added
        more text about Update Manager anonymous information gathering.



git-svn-id: https://svn.code.sf.net/p/pandora/code/trunk@1067 c3f86ba8-e40f-0410-aaad-9ba5e7f4b01f
---
 pandora_console/ChangeLog                     |  5 +++++
 .../update_manager/lib/libupdate_manager.php  | 17 +++++++++++++++++
 .../lib/libupdate_manager_client.php          | 16 ++++++++++++++++
 .../lib/libupdate_manager_components.php      | 17 +++++++++++++++++
 .../lib/libupdate_manager_updates.php         | 17 +++++++++++++++++
 .../lib/libupdate_manager_utils.php           | 17 +++++++++++++++++
 .../update_manager/lib/load_updatemanager.php | 16 ++++++++++++++++
 .../update_manager/load_updatemanager.php     | 16 ++++++++++++++++
 .../extensions/update_manager/main.php        | 19 +++++++++++--------
 9 files changed, 132 insertions(+), 8 deletions(-)

diff --git a/pandora_console/ChangeLog b/pandora_console/ChangeLog
index 13da9566f0..7e22ce40a1 100644
--- a/pandora_console/ChangeLog
+++ b/pandora_console/ChangeLog
@@ -1,3 +1,8 @@
+2008-09-02  Sancho Lerena <slerena@gmail.com>
+
+	*  extensions/update_manager*: Updated GPL header. Added 
+	more text about Update Manager anonymous information gathering.
+
 2008-09-02  Esteban Sanchez  <estebans@artica.es>
 
 	* extensions/update_manager.php: Style correction. Removed force
diff --git a/pandora_console/extensions/update_manager/lib/libupdate_manager.php b/pandora_console/extensions/update_manager/lib/libupdate_manager.php
index 03996e8499..4923ff5366 100644
--- a/pandora_console/extensions/update_manager/lib/libupdate_manager.php
+++ b/pandora_console/extensions/update_manager/lib/libupdate_manager.php
@@ -1,5 +1,22 @@
 <?php
 
+// Pandora FMS - the Flexible Monitoring System
+// ============================================
+// Copyright (c) 2008 Artica Soluciones Tecnologicas, http://www.artica.es
+// Please see http://pandora.sourceforge.net for full contribution list
+
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation for version 2.
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+
+
 /* PEAR DB manage abstraction */
 $prev_level = error_reporting (0);
 if ((include_once ('DB.php')) != 1)
diff --git a/pandora_console/extensions/update_manager/lib/libupdate_manager_client.php b/pandora_console/extensions/update_manager/lib/libupdate_manager_client.php
index 90b4b46733..664a634bfa 100644
--- a/pandora_console/extensions/update_manager/lib/libupdate_manager_client.php
+++ b/pandora_console/extensions/update_manager/lib/libupdate_manager_client.php
@@ -1,5 +1,21 @@
 <?php
 
+// Pandora FMS - the Flexible Monitoring System
+// ============================================
+// Copyright (c) 2008 Artica Soluciones Tecnologicas, http://www.artica.es
+// Please see http://pandora.sourceforge.net for full contribution list
+
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation for version 2.
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+
 $prev_level = error_reporting (0);
 if ((include_once ('XML/RPC.php')) != 1)
 	die ('<p>PEAR::XML_RPC not found. Please install it with: <pre>pear install XML_RPC</pre></p>');
diff --git a/pandora_console/extensions/update_manager/lib/libupdate_manager_components.php b/pandora_console/extensions/update_manager/lib/libupdate_manager_components.php
index a4e587fd55..bc8b4fbc08 100644
--- a/pandora_console/extensions/update_manager/lib/libupdate_manager_components.php
+++ b/pandora_console/extensions/update_manager/lib/libupdate_manager_components.php
@@ -1,5 +1,22 @@
 <?php
 
+// Pandora FMS - the Flexible Monitoring System
+// ============================================
+// Copyright (c) 2008 Artica Soluciones Tecnologicas, http://www.artica.es
+// Please see http://pandora.sourceforge.net for full contribution list
+
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation for version 2.
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+
+
 function um_component_database_get_data ($component_db) {
 	$db = um_component_db_connect ();
 	
diff --git a/pandora_console/extensions/update_manager/lib/libupdate_manager_updates.php b/pandora_console/extensions/update_manager/lib/libupdate_manager_updates.php
index fd91ed55fd..d7bbb1aab0 100644
--- a/pandora_console/extensions/update_manager/lib/libupdate_manager_updates.php
+++ b/pandora_console/extensions/update_manager/lib/libupdate_manager_updates.php
@@ -1,5 +1,22 @@
 <?php
 
+// Pandora FMS - the Flexible Monitoring System
+// ============================================
+// Copyright (c) 2008 Artica Soluciones Tecnologicas, http://www.artica.es
+// Please see http://pandora.sourceforge.net for full contribution list
+
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation for version 2.
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+
+
 function um_update_get_last_from_filename ($component_name, $filename) {
 	global $db;
 	
diff --git a/pandora_console/extensions/update_manager/lib/libupdate_manager_utils.php b/pandora_console/extensions/update_manager/lib/libupdate_manager_utils.php
index 94bc190783..fe5a0e71b9 100644
--- a/pandora_console/extensions/update_manager/lib/libupdate_manager_utils.php
+++ b/pandora_console/extensions/update_manager/lib/libupdate_manager_utils.php
@@ -1,5 +1,22 @@
 <?php
 
+// Pandora FMS - the Flexible Monitoring System
+// ============================================
+// Copyright (c) 2008 Artica Soluciones Tecnologicas, http://www.artica.es
+// Please see http://pandora.sourceforge.net for full contribution list
+
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation for version 2.
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+
+
 function add_prefix (&$string, $key, $prefix) {
 	$string = $prefix.'/'.$string;
 }
diff --git a/pandora_console/extensions/update_manager/lib/load_updatemanager.php b/pandora_console/extensions/update_manager/lib/load_updatemanager.php
index 41494cb595..289888a37d 100644
--- a/pandora_console/extensions/update_manager/lib/load_updatemanager.php
+++ b/pandora_console/extensions/update_manager/lib/load_updatemanager.php
@@ -1,5 +1,21 @@
 <?php
 
+// Pandora FMS - the Flexible Monitoring System
+// ============================================
+// Copyright (c) 2008 Artica Soluciones Tecnologicas, http://www.artica.es
+// Please see http://pandora.sourceforge.net for full contribution list
+
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation for version 2.
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+
 
 /* Change to E_ALL for development/debugging */
 error_reporting (E_ALL);
diff --git a/pandora_console/extensions/update_manager/load_updatemanager.php b/pandora_console/extensions/update_manager/load_updatemanager.php
index 0183bbab88..19fd96a55a 100644
--- a/pandora_console/extensions/update_manager/load_updatemanager.php
+++ b/pandora_console/extensions/update_manager/load_updatemanager.php
@@ -1,5 +1,21 @@
 <?php
 
+// Pandora FMS - the Flexible Monitoring System
+// ============================================
+// Copyright (c) 2008 Artica Soluciones Tecnologicas, http://www.artica.es
+// Please see http://pandora.sourceforge.net for full contribution list
+
+// This program is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public License
+// as published by the Free Software Foundation for version 2.
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+
 
 /* Change to E_ALL for development/debugging */
 error_reporting (E_ALL);
diff --git a/pandora_console/extensions/update_manager/main.php b/pandora_console/extensions/update_manager/main.php
index 637fbe7961..6a94822ea5 100644
--- a/pandora_console/extensions/update_manager/main.php
+++ b/pandora_console/extensions/update_manager/main.php
@@ -1,12 +1,13 @@
 <?php
-// Pandora - the Free monitoring system
-// ====================================
-// Copyright (c) 2008 Esteban Sanchez, estebans@artica.es
-// Copyright (c) 2008 Artica Soluciones Tecnologicas S.L, info@artica.es
+
+// Pandora FMS - the Flexible Monitoring System
+// ============================================
+// Copyright (c) 2008 Artica Soluciones Tecnologicas, http://www.artica.es
+// Please see http://pandora.sourceforge.net for full contribution list
+
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
-// as published by the Free Software Foundation;  version 2
-// of the License, or (at your option) any later version.
+// as published by the Free Software Foundation for version 2.
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -32,15 +33,17 @@ $db =& um_db_connect ('mysql', $config['dbhost'], $config['dbuser'],
 
 $settings = um_db_load_settings ();
 
-echo '<h3>'.__('Update manager').'</h3>';
+echo '<h2>'.__('Update manager').'</h2>';
 
 if ($settings->customer_key == FREE_USER) {
-	echo '<div class="notify" style="width: 80%" >';
+	echo '<div class="notify" style="width: 80%; text-align:left;" >';
 	echo '<img src="images/information.png" /> ';
 	/* Translators: Do not translade Update Manager, it's the name of the program */
 	echo __('The new <a href="http://updatemanager.sourceforge.net">Update Manager</a> client is shipped with the new Pandora FMS 2.0. It lets systems administrators to do not need to update their PandoraFMS manually since the Update Manager is the one getting new modules, new plugins and new features (even full migrations tools for future versions) automatically');
 	echo '<p />';
 	echo __('Update Manager is one of the most advanced features of PandoraFMS 2.0 Enterprise version, for more information visit <a href="http://pandorafms.com">http://pandorafms.com</a>');
+	echo '<p />';
+	echo __('Update Manager sends anonymous information about Pandora FMS usage (number of agents and modules running). To disable it, just delete extension or remove remote server address from Update Manager plugin setup.');
 	echo '</div>';
 }